@@ -79,7 +79,7 @@ fn main() {
 
     let format_arg = Arg::with_name("format")
         .short("f").long("format")
-        .takes_value(true).value_name("FORMAT").default_value("text")
+        .takes_value(true).value_name("FORMAT")
         .help(
             "The output format. Valid built-in formats are ical, csv, json, \
             ids, and text. Documentation on defining custom formats can be \
